@@ -1,6 +1,6 @@
 package Bundle::Slash;
 
-$Bundle::Slash::VERSION = '1.0.8';
+$Bundle::Slash::VERSION = '1.0.10';
 
 1;
 
@@ -17,20 +17,22 @@ C<perl -MCPAN -e 'install "Bundle::Slash"'>
 
 =head1 CONTENTS
 
-Bundle::CPAN	- File::Spec,Digest::MD5,Compress::Zlib,libnet,Archive::Tar,Data::Dumper
+Bundle::CPAN		- File::Spec,Digest::MD5,Compress::Zlib,libnet,Archive::Tar,Data::Dumper
 
-Bundle::LWP	- URI,HTML::Parser,MIME::Base64
+Bundle::LWP		- URI,HTML::Parser,MIME::Base64
 
-Bundle::DBI	- Storable
+Bundle::DBI		- Storable
 
 DBI::FAQ
 
-Bundle::DBD::mysql  - Data::ShowTable
+Bundle::DBD::mysql	- Data::ShowTable
 
-Date::Parse         - TimeDate
+Date::Parse		- TimeDate
 
 XML::Parser
 
+XML::RSS
+
 Date::Manip
 
 Mail::Sendmail
@@ -43,15 +45,14 @@ Apache::DBILogger
 
 Image::Size
 
+Template		- Template Toolkit
+
 
 =head1 DESCRIPTION
 
 mod_perl must be installed by hand, because of the special configuration
 required for it.
 
-IPC::Shareable no longer required for IPC, since we are no longer doing
-IPC.
-
 If CPAN starts downloading "perl-5.6.0" or somesuch, ctrl-C it, exit
 the CPAN shell, and start it again.  The latest CPAN.pm version does not
 have this problem, but older ones do, and you may have an older one
